@@ -37,9 +37,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston,
- * MA 02111-1307, USA.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * As a special exception, the authors of SANE give permission for
  * additional uses of the libraries contained in this release of SANE.
@@ -110,7 +108,7 @@ static Byte ioDataFromSPPFast( pScanData ps )
 
 	/* read low nibble */
 	tmp = _INB_STATUS( ps );
-	
+
 	/* combine with low nibble */
     bData |= (tmp >> 4);
 
@@ -141,7 +139,7 @@ static Byte ioDataFromSPPMiddle( pScanData ps )
 	/* read low nibble */
 	_INB_STATUS( ps );
 	tmp = _INB_STATUS( ps );
-	
+
 	/* combine with low nibble */
     bData |= (tmp >> 4);
 
@@ -174,7 +172,7 @@ static UChar ioDataFromSPPSlow( pScanData ps )
 	_INB_STATUS( ps );
 	_INB_STATUS( ps );
 	tmp = _INB_STATUS( ps );
-	
+
 	/* combine with low nibble */
     bData |= (tmp >> 4);
 
@@ -209,7 +207,7 @@ static UChar ioDataFromSPPSlowest( pScanData ps )
 	_INB_STATUS( ps );
 	_INB_STATUS( ps );
 	tmp = _INB_STATUS( ps );
-	
+
 	/* combine with low nibble */
     bData |= (tmp >> 4);
 
@@ -259,21 +257,11 @@ static Bool fnEPPRead( pScanData ps, pUChar pBuffer, ULong ulSize )
 
 	if( _IS_ASIC98(ps->sCaps.AsicID)) {
 
-#ifndef __KERNEL__
 		sanei_pp_set_datadir( ps->pardev, SANEI_PP_DATAIN );
-#else
-		_OUTB_CTRL( ps, (_CTRL_GENSIGNAL + _CTRL_DIRECTION));
-		_DO_UDELAY( 1 );
-#endif
 		for( i = 0; i < ulSize; i++ )
 			pBuffer[i] = _INB_EPPDATA( ps );
 
-#ifndef __KERNEL__
 		sanei_pp_set_datadir( ps->pardev, SANEI_PP_DATAOUT );
-#else
-		_OUTB_CTRL( ps, _CTRL_GENSIGNAL );
-		_DO_UDELAY( 1 );
-#endif
 	} else {
 
 		for( i = 0; i < ulSize; i++ )
@@ -292,26 +280,20 @@ static Bool fnBiDirRead( pScanData ps, pUChar pBuffer, ULong ulSize )
 	start = _CTRL_START_BIDIREAD;
 	end   = _CTRL_END_BIDIREAD;
 
-#ifndef __KERNEL__
 	sanei_pp_set_datadir( ps->pardev, SANEI_PP_DATAIN );
 
 	if( !sanei_pp_uses_directio()) {
 		start &= ~_CTRL_DIRECTION;
 		end   &= ~_CTRL_DIRECTION;
 	}
-#else
-	if( _IS_ASIC98(ps->sCaps.AsicID)) {
-		_OUTB_CTRL( ps, (_CTRL_GENSIGNAL + _CTRL_DIRECTION));
-	}
-#endif
 
 	switch( ps->IO.delay ) {
 
 		case 0:
 		    for( ; ulSize; ulSize--, pBuffer++ ) {
-				_OUTB_CTRL( ps, start );   
+				_OUTB_CTRL( ps, start );
 				*pBuffer = _INB_DATA( ps );
-				_OUTB_CTRL( ps, end );   
+				_OUTB_CTRL( ps, end );
 			}
 			break;
 
@@ -327,7 +309,7 @@ static Bool fnBiDirRead( pScanData ps, pUChar pBuffer, ULong ulSize )
 				_DO_UDELAY( 1 );
 			}
 			break;
-		
+
 		default:
 			_DO_UDELAY( 2 );
 		    for(; ulSize; ulSize--, pBuffer++ ) {
@@ -343,13 +325,7 @@ static Bool fnBiDirRead( pScanData ps, pUChar pBuffer, ULong ulSize )
 
 	}
 
-#ifndef __KERNEL__
 	sanei_pp_set_datadir( ps->pardev, SANEI_PP_DATAOUT );
-#else
-	if( _IS_ASIC98(ps->sCaps.AsicID)) {
-		_OUTB_CTRL( ps, _CTRL_GENSIGNAL );
-	}
-#endif
 	return _TRUE;
 }
 
@@ -446,7 +422,7 @@ static Bool ioP98OpenScanPath( pScanData ps )
 {
     Byte  tmp;
     ULong dw;
-	ULong dwTime = 1;
+//	ULong dwTime = 1;	// Doesn't seem to be used. [RL]
 
 	if( 0 == ps->IO.bOpenCount ) {
 
@@ -466,7 +442,7 @@ static Bool ioP98OpenScanPath( pScanData ps )
 #endif
 			} else {
 				ioP98003EstablishScannerConnection( ps, dw );
-			}			
+			}
 
 			_INB_STATUS( ps );
 			tmp = _INB_STATUS( ps );
@@ -481,7 +457,7 @@ static Bool ioP98OpenScanPath( pScanData ps )
 				ps->IO.bOpenCount = 0;
 			}
 
-			dwTime++;
+//			dwTime++;	// Doesn't seem to be used. [RL]
 		}
 		DBG( DBG_IO, "ioP98OpenScanPath() failed!\n" );
 		return _FALSE;
@@ -524,7 +500,7 @@ static void ioCloseScanPath( pScanData ps )
  * (ASIC 9800x only)
  */
 static int ioP98ReadWriteTest( pScanData ps )
-{	
+{
 	UChar  tmp;
 	ULong  ul;
 	pUChar buffer;
@@ -539,10 +515,10 @@ static int ioP98ReadWriteTest( pScanData ps )
 
 	/* prepare content */
 	for( ul = 0; ul < _MEMTEST_SIZE; ul++ )
-	    buffer[ul] = (UChar)ul;	
+	    buffer[ul] = (UChar)ul;
 
 	ps->OpenScanPath(ps);
-	
+
 	/* avoid switching to Lamp0, when previously scanned in transp./neg mode */
 	tmp = ps->bLastLampStatus + _SCAN_BYTEMODE;
 	IODataToRegister( ps, ps->RegScanControl, tmp );
@@ -595,7 +571,7 @@ static void ioSPPWrite( pScanData ps, pUChar pBuffer, ULong size )
 	DBG( DBG_IO , "Moving %u bytes to scanner, IODELAY = %u...\n",
 					size, ps->IO.delay );
 	switch( ps->IO.delay ) {
-	
+
 		case 0:
 		    for (; size; size--, pBuffer++) {
 				_OUTB_DATA( ps, *pBuffer );
@@ -603,7 +579,7 @@ static void ioSPPWrite( pScanData ps, pUChar pBuffer, ULong size )
 				_OUTB_CTRL( ps, _CTRL_END_DATAWRITE );
         	}
 			break;
-		
+
 		case 1:
 		case 2:
 		    for (; size; size--, pBuffer++) {
@@ -647,7 +623,7 @@ static void ioEnterReadMode( pScanData ps )
 		ps->IO.bOldControlValue = _INB_CTRL( ps );
 
 	/* ask ASIC to enter read mode */
-	IORegisterToScanner( ps, ps->RegReadDataMode );	
+	IORegisterToScanner( ps, ps->RegReadDataMode );
 }
 
 /************************ exported functions *********************************/
@@ -750,7 +726,7 @@ _LOC void IODataToScanner( pScanData ps, Byte bValue )
 	/* notify asic there is data */
     _OUTB_CTRL( ps, _CTRL_START_DATAWRITE );
 	_DO_UDELAY( deltime );
-						
+
 		/* end write cycle */
    	_OUTB_CTRL( ps, _CTRL_END_DATAWRITE );
 	_DO_UDELAY( deltime-1 );
@@ -767,7 +743,7 @@ _LOC void IODataToRegister( pScanData ps, Byte bReg, Byte bData )
 #endif
 
 	/* specify register */
-    IORegisterToScanner( ps, bReg );	
+    IORegisterToScanner( ps, bReg );
 
 	/* then write the content */
 	IODataToScanner( ps, bData );
@@ -955,45 +931,4 @@ _LOC void IOReadScannerImageData( pScanData ps, pUChar pBuf, ULong size )
 		ps->OpenScanPath( ps );
 }
 
-#ifdef __KERNEL__
-
-/** the wrapper functions to support delayed and non-delayed I/O
- */
-_LOC void IOOut( Byte data, UShort port )
-{
-	DBG( DBG_IOF, "outb(0x%04x, 0x%02x)\n", port, data );
-	outb( data, port );
-}
-
-_LOC void IOOutDelayed( Byte data, UShort port )
-{
-	DBG( DBG_IOF, "outb_p(0x%04x, 0x%02x)\n", port, data );
-	outb_p( data, port );
-}
-
-_LOC Byte IOIn( UShort port )
-{
-#ifdef DEBUG
-	Byte data = inb( port );
-
-	DBG( DBG_IOF, "inb(0x%04x) = 0x%02x\n", port, data );
-	return data;
-#else
-	return inb( port );
-#endif
-}
-
-_LOC Byte IOInDelayed( UShort port )
-{
-#ifdef DEBUG
-	Byte data = inb_p( port );
-
-	DBG( DBG_IOF, "inb_p(0x%04x) = 0x%02x\n", port, data );
-	return data;
-#else
-	return inb_p( port );
-#endif
-}
-#endif /* guard __KERNEL__ */
-
 /* END PLUSTEK-PP_IO.C ......................................................*/
