@@ -2,8 +2,8 @@
 /* ------------------------------------------------------------------------- */
 
 /* umax-uc1200s.c: inquiry for UMAX scanner uc1200s
-  
-   (C) 1997-2001 Oliver Rauch
+
+   (C) 1997-2002 Oliver Rauch
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
@@ -16,9 +16,7 @@
    General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-   MA 02111-1307, USA.
+   along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
    As a special exception, the authors of SANE give permission for
    additional uses of the libraries contained in this release of SANE.
@@ -59,13 +57,13 @@ static unsigned char UC1200S_INQUIRY[] =
 /* 28 - 29 reserved */
 	0x00, 0x00,
 
-/* 2a - 35 exposure times */	
+/* 2a - 35 exposure times */
 	0x00, 0x00,
 	0x00, 0x00, 0x00, 0x00,
 	0x00, 0x00, 0x00, 0x00,
 	0x00, 0x00,
 
-/* 36 - 37 reserved */	
+/* 36 - 37 reserved */
 	0x00, 0x00,
 
 /* 38 - 5f scsi reserved */
@@ -78,7 +76,7 @@ static unsigned char UC1200S_INQUIRY[] =
 /* 60 -62 scanner capability*/
 	0x2f,
 	0x0c,
-	0x07, 
+	0x07,
 
 /* 63 reserved */
 	0x00,
@@ -151,7 +149,7 @@ static unsigned char UC1200S_INQUIRY[] =
 
 /* 8a-8b dor max scan width in 0.01 inch */
 	0x00, 0x00,
-	
+
 /* 8c-8d dor max scan length in 0.01 inch */
 	0x00, 0x00,
 
